==> collective.buildbot-0.2.0.tar.gz: collective.buildbot-0.2.0/collective/buildbot/tests/test_docs.py <==
# -*- coding: utf-8 -*-
"""
Doctest runner for 'collective.buildbot'.
"""
__docformat__ = 'restructuredtext'

from os.path import join
import unittest
import zc.buildout.testing

from zope.testing import doctest, renormalizing
from collective.buildbot import project

optionflags =  (doctest.ELLIPSIS |
                doctest.NORMALIZE_WHITESPACE |
                doctest.REPORT_ONLY_FIRST_FAILURE)

def setUp(test):
    zc.buildout.testing.buildoutSetUp(test)

    # Install any other recipes that should be available in the tests
    zc.buildout.testing.install_develop('zc.recipe.egg', test)
    zc.buildout.testing.install_develop('virtualenv', test)
    zc.buildout.testing.install_develop('zope.interface', test)
    zc.buildout.testing.install_develop('Twisted', test)
    zc.buildout.testing.install_develop('buildbot', test)

    # Install the recipe in develop mode
    zc.buildout.testing.install_develop('collective.buildbot', test)

def test_suite():
    test_files = [
                  'master.txt',
                  'slave.txt',
                  'project.txt',
                  'poller.txt',
                  'fullexample.txt',
                 ]
    suite = unittest.TestSuite([
            doctest.DocFileSuite(
                join('..', 'docs', filename),
                setUp=setUp,
                tearDown=zc.buildout.testing.buildoutTearDown,
                optionflags=optionflags,
                checker=renormalizing.RENormalizing([
                        # If want to clean up the doctest output you
                        # can register additional regexp normalizers
                        # here. The format is a two-tuple with the RE
                        # as the first item and the replacement as the
                        # second item, e.g.
                        # (re.compile('my-[rR]eg[eE]ps'), 'my-regexps')
                        zc.buildout.testing.normalize_path,
                        ]),
                )
            for filename in test_files])
    suite.addTest(doctest.DocTestSuite(project))
    return suite

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')

==> collective.buildbot-0.3.0.tar.gz: collective.buildbot-0.3.0/collective/buildbot/tests/test_docs.py <==
# -*- coding: utf-8 -*-
"""
Doctest runner for 'collective.buildbot'.
"""
__docformat__ = 'restructuredtext'

from os.path import join
import unittest
import zc.buildout.testing

from zope.testing import doctest, renormalizing
import collective.buildbot.poller
import collective.buildbot.project
import collective.buildbot.project_recipe

optionflags =  (doctest.ELLIPSIS |
                doctest.NORMALIZE_WHITESPACE |
                doctest.REPORT_ONLY_FIRST_FAILURE)

def setUp(test):
    zc.buildout.testing.buildoutSetUp(test)

    # Install any other recipes that should be available in the tests
    zc.buildout.testing.install_develop('zc.recipe.egg', test)
    zc.buildout.testing.install_develop('virtualenv', test)
    zc.buildout.testing.install_develop('zope.interface', test)
    zc.buildout.testing.install_develop('Twisted', test)
    zc.buildout.testing.install_develop('buildbot', test)
    zc.buildout.testing.install_develop('pyflakes', test)

    # Install the recipe in develop mode
    zc.buildout.testing.install_develop('collective.buildbot', test)

def test_suite():

    # doc file suite
    test_files = [
                  'master.txt',
                  'slave.txt',
                  'project.txt',
                  'poller.txt',
                  'fullexample.txt',
                 ]
    suite = unittest.TestSuite([
            doctest.DocFileSuite(
                join('..', 'docs', filename),
                setUp=setUp,
                tearDown=zc.buildout.testing.buildoutTearDown,
                optionflags=optionflags,
                checker=renormalizing.RENormalizing([
                        # If want to clean up the doctest output you
                        # can register additional regexp normalizers
                        # here. The format is a two-tuple with the RE
                        # as the first item and the replacement as the
                        # second item, e.g.
                        # (re.compile('my-[rR]eg[eE]ps'), 'my-regexps')
                        zc.buildout.testing.normalize_path,
                        ]),
                )
            for filename in test_files])

    # doc test suite
    suite.addTest(doctest.DocTestSuite(collective.buildbot.poller))
    suite.addTest(doctest.DocTestSuite(collective.buildbot.project))
    suite.addTest(doctest.DocTestSuite(collective.buildbot.project_recipe))
    return suite

if __name__ == '__main__':
    unittest.main(defaultTest='test_suite')
